@@ -314,17 +314,23 @@ def write_uuu_script(target, image, uboot, mods):
                                        mods=mods))
 
 
-def wait_for_librem(librem_msg="default"):
+def wait_for_librem(librem_msg=None):
     found = False
     printed_msg = False
 
-    if librem_msg == "default":
+    if librem_msg is None:
         librem_msg = """
-            Turn all Hardware-Kill-Switches off
-            Remove battery
-            Hold volume-up
-            Insert the USB-c cable: (red light blinks, no green light)
-            Reinsert the battery: (red light is constantly on, the script will continue)\n\nSearching..."""
+            Enter the flashing mode by holding volume-up button while turning the phone on.
+
+            If it's not detected, follow these steps:
+            - Ensure that the phone is powered off
+            - Turn all Hardware-Kill-Switches off
+            - Unplug the USB cable if connected
+            - Remove battery
+            - Hold volume-up button
+            - Insert the USB-C cable (red light blinks, no green light)
+            - Reinsert the battery (red and green lights constantly on, the script will continue)
+            - Release volume-up button\n\nSearching..."""
 
     while not found:
         returned_text = subprocess.check_output("lsusb", shell=True, universal_newlines=True)
@@ -417,6 +423,8 @@ def main():
     parser.add_argument('--download-attempts', type=int, default=RETRIES,
                         help="Maximum number of attempts to resume "
                         "image download. 0: unlimited, default is {}".format(RETRIES))
+    parser.add_argument('--skip-download', action='store_true', default=False,
+                        help='Use a local image and uboot instead of downloading')
     parser.add_argument('--variant', choices=['plain', 'luks'], default=IMAGE_VARIANT,
                         help="Image variant to download ( plain, luks ), "
                         "default is '{}'".format(IMAGE_VARIANT))
@@ -489,11 +497,20 @@ def main():
         uboot_target = os.path.join(outdir, UBOOT.format(uboot_board))
         uuu_target = os.path.join(outdir, UUU_SCRIPT.format(board))
 
-        download_image(urljoin(image_ref['url'], 'artifact/{}.xz').format(IMAGE.format(board)),
-                       image_target, args.download_attempts)
-        download_uboot(urljoin(uboot_ref['url'],
-                       'artifact/output/uboot-{}/{}'.format(uboot_board, UBOOT.format(uboot_board))),
-                       uboot_target)
+        if args.skip_download:
+            if args.dir is None:
+                logging.error("Skipping download requires a directory to be specified with --dir")
+                return 1
+            if (not os.path.exists(image_target)) or (not os.path.exists(uboot_target)):
+                logging.error(f"Requested to skip download but at least one of image ({image_target}) or uboot ({uboot_target}) is missing")
+                return 1
+            logging.info(f"Skipping download and using local image '{image_target}'")
+        else:
+            download_image(urljoin(image_ref['url'], 'artifact/{}.xz').format(IMAGE.format(board)),
+                           image_target, args.download_attempts)
+            download_uboot(urljoin(uboot_ref['url'],
+                           'artifact/output/uboot-{}/{}'.format(uboot_board, UBOOT.format(uboot_board))),
+                           uboot_target)
         write_uuu_script(uuu_target, image_target, uboot_target, uuu_mods)
         if not args.skip_flash:
             if board == "devkit":
@@ -501,6 +518,7 @@ def main():
             else:
                 wait_for_librem()
             flash_image(uuu_target, args.debug)
+            print("Flashing complete. You can now turn the device off.")
     except VerifyImageException as e:
         logging.error(e)
         return 1
